selection/max.hpp

The selection/max.hpp header defines a macro that returns the greater of two elements.

#### Usage

#include <boost/preprocessor/selection/max.hpp>

#### Contents

- BOOST_PP_MAX
- BOOST_PP_MAX_D

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)